==> dpsrc_1_2005.tar.gz: gl_src.f <==
      SUBROUTINE GLDRAW(IX,IY,NPTS)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GLATTR(ICODE,ISTYLE,AWIDTH)
      RETURN
      END
      SUBROUTINE GLREFL(AX,AY,NPTS)
      INTEGER AX(*), AY(*)
      RETURN
      END
      SUBROUTINE GLPOIN(IX,IY,ASIZE)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GLCIRC(IX,IY,IRAD,IFILL,JCOL)
      RETURN
      END
      SUBROUTINE GLCHEC(IEXPOS,IERR)
      RETURN
      END
      SUBROUTINE GLUPDA(IFRONT)
      RETURN
      END
      SUBROUTINE GLCLEA()
      RETURN
      END
      SUBROUTINE GLSAVG(IFILE,IERR)
      INTEGER IFILE(*)
      RETURN
      END
      SUBROUTINE GLRESG(IFILE,ITITLE,IWIND,IWINDN,IERR)
      INTEGER IFILE(*),ITITLE(*)
      RETURN
      END
      SUBROUTINE GLCYCL(IERR,IBUTTN)
      RETURN
      END
      SUBROUTINE GLLOC(IXRET,IYRET,IERR)
      RETURN
      END
      SUBROUTINE GLCLDE
      RETURN
      END
      SUBROUTINE GLOPDE
      RETURN
      END
      SUBROUTINE GLEND
      RETURN
      END
      SUBROUTINE GLRGFL(IX,IY,NPTS)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GLSECO(INDX,RED,GREEN,BLUE)
      RETURN
      END
      SUBROUTINE GLSEPA(INDEX)
      RETURN
      END
      SUBROUTINE GLTEXV(ISTRNG,AXPOS,AYPOS,IJUSTH,IJUSTV,IERROR)
      INTEGER ISTRNG(*)
      RETURN
      END
      SUBROUTINE GLTEXH(ISTRNG,AXPOS,AYPOS,IJUSTH,IJUSTV,IERROR)
      INTEGER ISTRNG(*)
      RETURN
      END
      SUBROUTINE GLTATT(IFONT,IERROR)
      INTEGER IFONT(*)
      RETURN
      END
      SUBROUTINE GLINIT(IXP,IYP,IOR,IXPIX,IYPIX,INAME,IWIND,ICOUNT,
     1                 IERR)
C
      INTEGER INAME(*)
C
      CHARACTER*4 IFEEDB
      CHARACTER*4 IPRINT
      CHARACTER*240 ICOUT
C
      COMMON /MACH/IRD,IPR,CPUMIN,CPUMAX,NUMBPC,NUMCPW,NUMBPW
      COMMON /PRINT/IFEEDB,IPRINT
      COMMON /TEXTOU/ICOUT,NCOUT,ILOUT
C
      WRITE(ICOUT,110)
  110 FORMAT('OPEN-GL DRIVER NOT INSTALLED ON THIS IMPLEMENTATION.')
      CALL DPWRST('XXX','BUG ')
      WRITE(ICOUT,120)
  120 FORMAT('CONTACT YOUR LOCAL SITE COORDINATER FOR MORE ',
     1       'INFORMATION.')
      CALL DPWRST('XXX','BUG ')
      RETURN
      END
      SUBROUTINE GLERAS(IXPIX,IYPIX,IOR,IXRET,IYRET,RED,BLUE,GREEN)
      RETURN
      END

==> dpsrc_2009_08_21.tar.gz: gl_src.f <==
      SUBROUTINE GLDRAW(IX,IY,NPTS)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GLATTR(ICODE,ISTYLE,AWIDTH)
      RETURN
      END
      SUBROUTINE GLREFL(AX,AY,NPTS)
      INTEGER AX(*), AY(*)
      RETURN
      END
      SUBROUTINE GLPOIN(IX,IY,ASIZE)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GLCIRC(IX,IY,IRAD,IFILL,JCOL)
      RETURN
      END
      SUBROUTINE GLCHEC(IEXPOS,IERR)
      RETURN
      END
      SUBROUTINE GLUPDA(IFRONT)
      RETURN
      END
      SUBROUTINE GLCLEA()
      RETURN
      END
      SUBROUTINE GLSAVG(IFILE,IERR)
      INTEGER IFILE(*)
      RETURN
      END
      SUBROUTINE GLRESG(IFILE,ITITLE,IWIND,IWINDN,IERR)
      INTEGER IFILE(*),ITITLE(*)
      RETURN
      END
      SUBROUTINE GLCYCL(IERR,IBUTTN)
      RETURN
      END
      SUBROUTINE GLLOC(IXRET,IYRET,IERR)
      RETURN
      END
      SUBROUTINE GLCLDE
      RETURN
      END
      SUBROUTINE GLOPDE
      RETURN
      END
      SUBROUTINE GLEND
      RETURN
      END
      SUBROUTINE GLRGFL(IX,IY,NPTS)
      INTEGER IX(*), IY(*)
      RETURN
      END
      SUBROUTINE GLSECO(INDX,RED,GREEN,BLUE)
      RETURN
      END
      SUBROUTINE GLSEPA(INDEX)
      RETURN
      END
      SUBROUTINE GLTEXV(ISTRNG,IXPOS,IYPOS,IJUSTH,IJUSTV,IERROR)
      INTEGER ISTRNG(*)
      RETURN
      END
      SUBROUTINE GLTEXH(ISTRNG,IXPOS,IYPOS,IJUSTH,IJUSTV,IERROR)
      INTEGER ISTRNG(*)
      RETURN
      END
      SUBROUTINE GLTATT(IFONT,IERROR)
      INTEGER IFONT(*)
      RETURN
      END
      SUBROUTINE GLINIT(IXP,IYP,IOR,IXPIX,IYPIX,INAME,IWIND,ICOUNT,
     1                 IERR)
C
      INTEGER INAME(*)
C
      CHARACTER*4 IFEEDB
      CHARACTER*4 IPRINT
      CHARACTER*240 ICOUT
C
      COMMON /MACH/IRD,IPR,CPUMIN,CPUMAX,NUMBPC,NUMCPW,NUMBPW
      COMMON /PRINT/IFEEDB,IPRINT
      COMMON /TEXTOU/ICOUT,NCOUT,ILOUT
C
      WRITE(ICOUT,110)
  110 FORMAT('OPEN-GL DRIVER NOT INSTALLED ON THIS IMPLEMENTATION.')
      CALL DPWRST('XXX','BUG ')
      WRITE(ICOUT,120)
  120 FORMAT('CONTACT YOUR LOCAL SITE COORDINATER FOR MORE ',
     1       'INFORMATION.')
      CALL DPWRST('XXX','BUG ')
      RETURN
      END
      SUBROUTINE GLERAS(IXPIX,IYPIX,IOR,IXRET,IYRET,RED,BLUE,GREEN)
      RETURN
      END
